@@ -10,11 +10,11 @@ SCOPE_MAP = {
              'online': ['community_basic_online', 'community_advanced_online'],
              'photo': ['community_basic_photo', 'community_advanced_photo'],
              'music': ['music_basic_r', 'music_basic_w'],
-             'movie': ['movie_basic_r', 'movie_basic_w'],
+             'movie': ['movie_basic_r', 'movie_basic_w', 'movie_advance_r', 'movie_private_celebrity'],
              'book': ['book_basic_r', 'book_basic_w'],
              'event': ['event_basic_r', 'event_basic_w,event_advanced_r'],
             }
 
 SCOPE = ','.join(reduce(lambda x, y: x + y, SCOPE_MAP.values()))
 
-TOKEN = '' #'0e6e7d9c101228e52b4b78d430367aaf'
+TOKEN = ''
